# PyCockByEmir

Bu kütüphane, boy uzunluğu ve ayak uzunluğu ile özel hesaplamalar yapar. :D

## Kurulum

```python
from sizeforemir import cocksize_formula

result = cocksize_formula(180, 25)
print(result)
